@@ -76,7 +76,7 @@ def imports(enums_module: str) -> str:
         "from decimal import Decimal",
         "from edgedb import RelativeDuration, AsyncIOClient, create_async_client",
         "from pydantic import BaseModel, Field, PrivateAttr, validator",
-        f"from {PATH_TO_MODULE} import Node, Resolver, NodeException, ResolverException, UpdateOperation, Batch, Unset, ComputedPropertyException, AppendixPropertyException, is_unset, from_str, enum_from_str, BasePatch, FilterConnector",
+        f"from {PATH_TO_MODULE} import Node, Resolver, NodeException, ResolverException, UpdateOperation, Batch, UNSET, UnsetType, ComputedPropertyException, AppendixPropertyException, from_str, enum_from_str, BasePatch, FilterConnector",
         f"from .{enums_module} import *",
         'EdgeResolverType = T.TypeVar("EdgeResolverType", bound=Resolver)',
     ]
@@ -119,13 +119,13 @@ async def {link.name}(
     self,
     resolver: {link_resolver_name} = None,
     refresh: bool = False,
-    force_use_stale: bool = False,
+    revert_to_first: bool = False,
 ) -> {link.type_str}:
     return await self.resolve(
         edge_name="{link.name}",
         edge_resolver=resolver or {link_resolver_name}(),
         refresh=refresh,
-        force_use_stale=force_use_stale,
+        revert_to_first=revert_to_first,
     )
     """
 
@@ -134,9 +134,7 @@ def build_resolver_link_function_str(node_resolver_name: str, link: Link) -> str
     link_resolver_name = f"{link.target.model_name}Resolver"
     return f"""
 def {link.name}(self, _: T.Optional[{link_resolver_name}] = None, /) -> {node_resolver_name}:
-    if "{link.name}" in self._nested_resolvers:
-        raise ResolverException("A resolver for `{link.name}` has already been provided.")
-    self._nested_resolvers["{link.name}"] = _ or {link_resolver_name}()
+    self._nested_resolvers.add("{link.name}", _ or {link_resolver_name}())
     return self
     """
 
@@ -165,7 +163,7 @@ def build_filter_functions_str(node_name: str, conversion_map: T.Dict[str, dict]
     )
     dict_fields_str = ", ".join([f'"{f}": {f}' for f in field_names])
     filter_by_str = f"""
-def filter_by(self, filter_connector: FilterConnector = None, {params_fields_str}) -> {node_name}Resolver:
+def filter_by(self, filter_connector: FilterConnector = FilterConnector.AND, {params_fields_str}) -> {node_name}Resolver:
     return super().filter_by(connector=filter_connector, **{{{dict_fields_str}}})
     """
     # now for filter in
@@ -173,7 +171,7 @@ def filter_by(self, filter_connector: FilterConnector = None, {params_fields_str
         [f"{f}: T.Optional[T.List[T.Any]] = None" for f in field_names]
     )
     filter_in_str = f"""
-def filter_in(self, filter_connector: FilterConnector = None, {params_fields_lst_str}) -> {node_name}Resolver:
+def filter_in(self, filter_connector: FilterConnector = FilterConnector.AND, {params_fields_lst_str}) -> {node_name}Resolver:
     return super().filter_in(connector=filter_connector, **{{{dict_fields_str}}})
     """
     return f"{filter_by_str}\n{filter_in_str}"
@@ -368,11 +366,11 @@ def build_node_and_resolver(
             if prop.is_computed:
                 exception_name = "ComputedPropertyException"
                 property_name = f"_{prop.name}"
-                property_str = f"{property_name}: T.Union[{type_str}, Unset] = PrivateAttr(default_factory=Unset)"
+                property_str = f"{property_name}: T.Union[{type_str}, UnsetType] = PrivateAttr(default_factory=UnsetType)"
             else:
                 exception_name = "AppendixPropertyException"
                 property_name = f"{prop.name}_"
-                property_str = f'{property_name}: T.Union[{type_str}, Unset] = Field(default_factory=Unset, alias="{prop.name}")'
+                property_str = f'{property_name}: T.Union[{type_str}, UnsetType] = Field(default_factory=UnsetType, alias="{prop.name}")'
             property_strs.append(property_str)
             val_str = "val"
             if "Set[" in type_str:
@@ -381,7 +379,7 @@ def build_node_and_resolver(
                 f"""
 @property
 def {prop.name}(self) -> {type_str}:
-    if is_unset(self.{property_name}):
+    if self.{property_name} is UNSET:
         if "{prop.name}" in self.extra:
             val = self.extra["{prop.name}"]
             self.{property_name} = {val_str}
@@ -426,9 +424,9 @@ def {prop.name}(self, {prop.name}: {type_str}) -> None:
                 patch_type_str = type_str
                 if prop.required and prop.default:
                     patch_type_str = f"T.Optional[{patch_type_str}]"
-                final_patch_type_str = f"T.Union[{patch_type_str}, Unset]"
+                final_patch_type_str = f"T.Union[{patch_type_str}, UnsetType]"
                 patch_property_strs.append(
-                    f"{prop.name}: {final_patch_type_str} = Field(default_factory=Unset)"
+                    f"{prop.name}: {final_patch_type_str} = Field(default_factory=UnsetType)"
                 )
 
     link_function_strs: T.List[str] = []
@@ -474,9 +472,9 @@ def {prop.name}(self, {prop.name}: {type_str}) -> None:
             patch_resolver_str = f"{link.target.model_name}Resolver"
             if (not link.required) or (link.required and link.default):
                 patch_resolver_str = f"T.Optional[{patch_resolver_str}]"
-            final_patch_resolver_str = f"T.Union[{patch_resolver_str}, Unset]"
+            final_patch_resolver_str = f"T.Union[{patch_resolver_str}, UnsetType]"
             patch_property_strs.append(
-                f"{link.name}: {final_patch_resolver_str} = Field(default_factory=Unset)"
+                f"{link.name}: {final_patch_resolver_str} = Field(default_factory=UnsetType)"
             )
 
     orm_config_str = build_orm_config(
