@@ -47,6 +47,9 @@ class FilterConnector(str, Enum):
     OR = " OR "
 
 
+from .nested_resolvers import NestedResolvers
+
+
 class Resolver(BaseModel, T.Generic[NodeType]):
     """Can construct an EdgeQL query string from this!"""
 
@@ -60,17 +63,48 @@ class Resolver(BaseModel, T.Generic[NodeType]):
     _offset: int = PrivateAttr(None)
     _extra_fields: str = PrivateAttr(None)
 
+    # this is for importing functions or libraries i think
     _modules: str = PrivateAttr(None)
 
     # this is just for updating
     _update_operation: UpdateOperation = PrivateAttr(None)
 
     _query_variables: T.Dict[str, T.Any] = PrivateAttr(default_factory=dict)
-    _nested_resolvers: T.Dict[str, "Resolver"] = PrivateAttr(default_factory=dict)
+    _nested_resolvers: NestedResolvers = PrivateAttr(default_factory=NestedResolvers)
 
     _fields_to_return: T.Set[str] = PrivateAttr(None)
     _fields_to_include: T.Set[str] = PrivateAttr(default_factory=set)
 
+    def to_compare_filter_str(self) -> str:
+        q_str = self.all_filters_str()
+        # add extra str
+        q_str += f", {self._extra_fields}"
+        for var_name, var_val in self._query_variables.items():
+            q_str = re.sub(
+                rf"(\$)({var_name})(\W*)", r"\1" + f"[({var_val})]" + r"\3", q_str
+            ).replace(f"[({var_val})]", f"{var_val}")
+        return q_str
+
+    def is_subset(self, other: "Resolver", should_debug: bool = False) -> bool:
+        # first compare top level resolver, then go down from there
+        # if self has more fields to return than other, self cannot be a subset
+        if set(self.get_fields_to_return()) - set(other.get_fields_to_return()):
+            if should_debug:
+                print(f"self {self.__class__.__name__} has more fields than other")
+            return False
+        # if self has different filters than other, self cannot be a subset
+        if self.to_compare_filter_str() != other.to_compare_filter_str():
+            if should_debug:
+                print(
+                    f"self {self.__class__.__name__} has diff filters, "
+                    f"{self.to_compare_filter_str()=} {other.to_compare_filter_str()=}"
+                )
+            return False
+        # now nested resolvers
+        if not self._nested_resolvers.is_subset(other._nested_resolvers):
+            return False
+        return True
+
     """PROPERTIES"""
 
     @classmethod
@@ -108,14 +142,16 @@ class Resolver(BaseModel, T.Generic[NodeType]):
     def _model_name(cls) -> str:
         return cls._node._model_name
 
-    def get_fields_to_return(self) -> T.Set[str]:
+    def get_fields_to_return(self) -> T.List[str]:
         """Include nested fields with DOT notation"""
         if self._fields_to_return is None:
-            return {
+            fields = {
                 *(self.get_aliases() - self._node._appendix_properties),
                 *self._fields_to_include,
             }
-        return self._fields_to_return
+        else:
+            fields = self._fields_to_return
+        return sorted(list(fields))
 
     @property
     def _filter_str(self) -> str:
@@ -227,7 +263,7 @@ class Resolver(BaseModel, T.Generic[NodeType]):
         self: ThisResolverType,
         filter_str: str,
         variables: T.Optional[T.Dict[str, T.Any]] = None,
-        connector: FilterConnector = None,
+        connector: FilterConnector = FilterConnector.AND,
     ) -> ThisResolverType:
         if self._filter and not connector:
             raise ResolverException(
@@ -238,12 +274,12 @@ class Resolver(BaseModel, T.Generic[NodeType]):
         if not self._filter:
             self._filter = ""
         else:
-            if connector:
+            if connector and self._filter:
                 self._filter += connector.value
         self._filter += filter_str
         return self
 
-    def filter_by(self, connector: FilterConnector = None, **kwargs):
+    def filter_by(self, connector: FilterConnector = FilterConnector.AND, **kwargs):
         """For now, only expecting one key value pair to be given, but could be more in future"""
         kwargs = {k: v for k, v in kwargs.items() if v is not None}
         if not kwargs:
@@ -261,7 +297,9 @@ class Resolver(BaseModel, T.Generic[NodeType]):
             filter_str=filter_str, variables=variables, connector=connector
         )
 
-    def filter_in(self, connector: FilterConnector = None, **kwargs: list):
+    def filter_in(
+        self, connector: FilterConnector = FilterConnector.AND, **kwargs: list
+    ):
         kwargs = {k: v for k, v in kwargs.items() if v is not None}
         if not kwargs:
             raise ResolverException("Nothing to filter by.")
@@ -355,7 +393,7 @@ class Resolver(BaseModel, T.Generic[NodeType]):
 
     def _get_nested_query_variables(self) -> T.Dict[str, T.Any]:
         query_variables = {**self._query_variables}
-        for nested_resolver in self._nested_resolvers.values():
+        for nested_resolver in self._nested_resolvers.all_resolvers():
             nested_query_variables = nested_resolver._get_nested_query_variables()
             if not nested_query_variables:
                 continue
@@ -393,12 +431,7 @@ class Resolver(BaseModel, T.Generic[NodeType]):
         s += ", ".join(self.get_fields_to_return())
         if self._extra_fields:
             s += f", {self._extra_fields}"
-        resolver_strs: T.List[str] = []
-        if not ignore_nested:
-            for field_name, resolver in self._nested_resolvers.items():
-                resolver_substring = f"{field_name}: {resolver.to_str()}"
-                resolver_strs.append(resolver_substring)
-        nested_resolver_str = ", ".join(resolver_strs)
+        nested_resolver_str = self._nested_resolvers.to_str()
         if nested_resolver_str:
             s += f", {nested_resolver_str}"
         s = f"{{ {s} }}"
@@ -513,7 +546,7 @@ class Resolver(BaseModel, T.Generic[NodeType]):
         # problem with this is aliases are currently also added to extra... do i want this?
         other_fields = set(raw_d.keys()) - self.get_aliases()
         for field_name in other_fields:
-            resolver: Resolver = self._nested_resolvers.get(field_name)
+            resolver = self._nested_resolvers.resolver_from_field_name(field_name)
             if resolver is None:
                 message = f"No nested resolver for {field_name=} found."
                 if error_for_extra_fields:
@@ -529,8 +562,9 @@ class Resolver(BaseModel, T.Generic[NodeType]):
                 else:
                     val = resolver.parse_nested_obj(nested_d)
                 value_to_save = val
+            edge_name = NestedResolvers.edge_from_field_name(field_name)
             node.cache.add(
-                key=field_name, resolver=resolver, val=value_to_save, raw_d=raw_d
+                edge=edge_name, resolver=resolver, val=value_to_save, raw_d=raw_d
             )
         node._used_resolver = self.copy(deep=True)
         node._original_dict = raw_d.copy()
